@@ -4,7 +4,6 @@ import (
 	"context"
 	"errors"
 	"fmt"
-	"log"
 	"os"
 	"time"
 
@@ -98,6 +97,19 @@ func main() {
 		},
 	}
 
+	verifyFlags := []cli.Flag{
+		&cli.StringFlag{
+			Name:        "target-dir",
+			Usage:       "set this option if you want to specify the directory you want to verify.",
+			DefaultText: "current directory",
+		},
+		&cli.BoolFlag{
+			Name:        "strict",
+			Usage:       "set this option if you want strict directory match validation.",
+			DefaultText: "non strict",
+		},
+	}
+
 	templateFlags := []cli.Flag{
 		&cli.BoolFlag{
 			Name:    "description",
@@ -124,7 +136,7 @@ func main() {
 
 	app := &cli.App{
 		Name: "gtree",
-		Usage: "This CLI generates directory trees and the directories itself using Markdown.\n" +
+		Usage: "This CLI uses Markdown to generate directory trees and directories itself, and also verifies directories.\n" +
 			fmt.Sprintf("The symbols that can be used in Markdown are '%s', '%s', '%s', and '%s'.", green("-"), green("+"), green("*"), green("#")),
 		Version: fmt.Sprintf("%s / revision %s", Version, Revision),
 		Commands: []*cli.Command{
@@ -146,6 +158,15 @@ func main() {
 				Before: notExistArgs,
 				Action: actionMkdir,
 			},
+			{
+				Name:    "verify",
+				Aliases: []string{"vf"},
+				Usage: "Verifies tree structure represented in markdown by comparing it with existing directories.\n" +
+					"Let's try 'gtree template | gtree verify'.",
+				Flags:  append(commonFlags, verifyFlags...),
+				Before: notExistArgs,
+				Action: actionVerify,
+			},
 			{
 				Name:    "template",
 				Aliases: []string{"t", "tmpl"},
@@ -184,7 +205,7 @@ func main() {
 	}
 
 	if err := app.Run(os.Args); err != nil {
-		log.Fatal(err)
+		fmt.Fprint(os.Stderr, err)
 	}
 }
 
@@ -283,6 +304,34 @@ func isInputStdin(path string) bool {
 	return path == "" || path == "-"
 }
 
+func actionVerify(c *cli.Context) error {
+	var (
+		in  = os.Stdin
+		err error
+	)
+	if !isInputStdin(c.Path("file")) {
+		in, err = os.Open(c.Path("file"))
+		if err != nil {
+			return exitErrOpen(err)
+		}
+		defer in.Close()
+	}
+
+	oi, err := optionIndentation(c)
+	if err != nil {
+		return exitErrOpts(err)
+	}
+	options := []gtree.Option{oi, gtree.WithTargetDir(c.String("target-dir"))}
+	if c.Bool("strict") {
+		options = append(options, gtree.WithStrictVerify())
+	}
+
+	if err := verify(in, options); err != nil {
+		return exitErrVerify(err)
+	}
+	return nil
+}
+
 func actionTemplate(c *cli.Context) error {
 	if c.Bool("description") {
 		return description.println()
