@@ -12,9 +12,12 @@ type treeSimple struct {
 	grower   growerSimple
 	spreader spreaderSimple
 	mkdirer  mkdirerSimple
+	verifier verifierSimple
 }
 
-func newTreeSimple(conf *config) iTree {
+var _ tree = (*treeSimple)(nil)
+
+func newTreeSimple(cfg *config) tree {
 	growerFactory := func(lastNodeFormat, intermedialNodeFormat branchFormat, dryrun bool, encode encode) growerSimple {
 		if encode != encodeDefault {
 			return newNopGrowerSimple()
@@ -33,69 +36,100 @@ func newTreeSimple(conf *config) iTree {
 		return newMkdirerSimple(fileExtensions)
 	}
 
+	verifierFactory := func(targetDir string, strict bool) verifierSimple {
+		return newVerifierSimple(targetDir, strict)
+	}
+
 	return &treeSimple{
 		grower: growerFactory(
-			conf.lastNodeFormat,
-			conf.intermedialNodeFormat,
-			conf.dryrun,
-			conf.encode,
+			cfg.lastNodeFormat,
+			cfg.intermedialNodeFormat,
+			cfg.dryrun,
+			cfg.encode,
 		),
 		spreader: spreaderFactory(
-			conf.encode,
-			conf.dryrun,
-			conf.fileExtensions,
+			cfg.encode,
+			cfg.dryrun,
+			cfg.fileExtensions,
 		),
 		mkdirer: mkdirerFactory(
-			conf.fileExtensions,
+			cfg.fileExtensions,
+		),
+		verifier: verifierFactory(
+			cfg.targetDir,
+			cfg.strictVerify,
 		),
 	}
 }
 
-func (t *treeSimple) output(w io.Writer, r io.Reader, conf *config) error {
-	rg := newRootGeneratorSimple(r, conf.space)
+func (t *treeSimple) output(w io.Writer, r io.Reader, cfg *config) error {
+	rg := newRootGeneratorSimple(r, cfg.space)
 	roots, err := rg.generate()
 	if err != nil {
 		return err
 	}
 
-	if err := t.grow(roots); err != nil {
+	if err := t.grower.grow(roots); err != nil {
 		return err
 	}
-	return t.spread(w, roots)
+	return t.spreader.spread(w, roots)
 }
 
-func (t *treeSimple) outputProgrammably(w io.Writer, root *Node, conf *config) error {
-	if err := t.grow([]*Node{root}); err != nil {
+func (t *treeSimple) outputProgrammably(w io.Writer, root *Node, cfg *config) error {
+	if err := t.grower.grow([]*Node{root}); err != nil {
 		return err
 	}
-	return t.spread(w, []*Node{root})
+	return t.spreader.spread(w, []*Node{root})
 }
 
-func (t *treeSimple) makedir(r io.Reader, conf *config) error {
-	rg := newRootGeneratorSimple(r, conf.space)
+func (t *treeSimple) mkdir(r io.Reader, cfg *config) error {
+	rg := newRootGeneratorSimple(r, cfg.space)
 	roots, err := rg.generate()
 	if err != nil {
 		return err
 	}
 
-	if err := t.grow(roots); err != nil {
+	if err := t.grower.grow(roots); err != nil {
 		return err
 	}
-	return t.mkdir(roots)
+	return t.mkdirer.mkdir(roots)
 }
 
-func (t *treeSimple) makedirProgrammably(root *Node, conf *config) error {
-	t.enableValidation()
+func (t *treeSimple) mkdirProgrammably(root *Node, cfg *config) error {
+	t.grower.enableValidation()
 	// when detect invalid node name, return error. process end.
-	if err := t.grow([]*Node{root}); err != nil {
+	if err := t.grower.grow([]*Node{root}); err != nil {
 		return err
 	}
-	if conf.dryrun {
+	if cfg.dryrun {
 		// when detected no invalid node name, output tree.
-		return t.spread(color.Output, []*Node{root})
+		return t.spreader.spread(color.Output, []*Node{root})
 	}
 	// when detected no invalid node name, no output tree.
-	return t.mkdir([]*Node{root})
+	return t.mkdirer.mkdir([]*Node{root})
+}
+
+func (t *treeSimple) verify(r io.Reader, cfg *config) error {
+	rg := newRootGeneratorSimple(r, cfg.space)
+	roots, err := rg.generate()
+	if err != nil {
+		return err
+	}
+
+	t.grower.enableValidation()
+	if err := t.grower.grow(roots); err != nil {
+		return err
+	}
+	return t.verifier.verify(roots)
+}
+
+func (t *treeSimple) verifyProgrammably(root *Node, cfg *config) error {
+	t.grower.enableValidation()
+	// when detect invalid node name, return error. process end.
+	if err := t.grower.grow([]*Node{root}); err != nil {
+		return err
+	}
+	return t.verifier.verify([]*Node{root})
 }
 
 // 関心事は各ノードの枝の形成
@@ -115,14 +149,8 @@ type mkdirerSimple interface {
 	mkdir([]*Node) error
 }
 
-func (t *treeSimple) grow(roots []*Node) error {
-	return t.grower.grow(roots)
-}
-
-func (t *treeSimple) spread(w io.Writer, roots []*Node) error {
-	return t.spreader.spread(w, roots)
-}
-
-func (t *treeSimple) mkdir(roots []*Node) error {
-	return t.mkdirer.mkdir(roots)
+// 関心事はディレクトリの検証
+// interfaceを使う必要はないが、growerSimple/spreaderSimpleと合わせたいため
+type verifierSimple interface {
+	verify([]*Node) error
 }
