@@ -8,15 +8,15 @@ import (
 
 // Output outputs a tree to w with r as Markdown format input.
 func Output(w io.Writer, r io.Reader, options ...Option) error {
-	conf := newConfig(options)
+	cfg := newConfig(options)
 
-	rg := newRootGenerator(r, conf.space)
+	rg := newRootGenerator(r, cfg.space)
 	roots, err := rg.generate()
 	if err != nil {
 		return err
 	}
 
-	tree := newTree(conf, roots)
+	tree := newTree(cfg, roots)
 	if err := tree.grow(); err != nil {
 		return err
 	}
